import React from 'react';
import './Meta2d.css';
import {
  Meta2d,
  register,
  registerAnchors,
  registerCanvasDraw,
} from '@meta2d/core';
import { flowPens, flowAnchors } from '@meta2d/flow-diagram';
import {
  activityDiagram,
  activityDiagramByCtx,
} from '@meta2d/activity-diagram';
import { classPens } from '@meta2d/class-diagram';
import { sequencePens, sequencePensbyCtx } from '@meta2d/sequence-diagram';
import { register as registerEcharts } from '@meta2d/chart-diagram';
import { registerHighcharts } from '@meta2d/chart-diagram';
import { registerLightningChart } from '@meta2d/chart-diagram';
import { formPens, formPath2DPens } from '@meta2d/form-diagram';
import { chartsPens } from '@meta2d/le5le-charts';
import { ftaPens, ftaPensbyCtx, ftaAnchors } from '@meta2d/fta-diagram';

let meta2d = null;

export default class Meta2dCom extends React.Component {
  constructor(props) {
    super(props);
  }

  componentDidMount() {
    const options = {
      // x: 10,
      // y: 10,
      width: 1920,
      height: 1080,
      background: '#1e2430',
      color: '#bdc7db',
    }
    meta2d = new Meta2d('meta2d',options);
    this.registerBasicDiagram();
    this._fetch('/json/data.json', function (text) {
      var data = JSON.parse(text);
      data.locked = 1;
      data.rule = false;
      meta2d.open(data);
      meta2d.fitSizeView(true, 0); //大屏充满屏幕
      // meta2d.fitView(true,0); //充满屏幕
    });
  }

  componentWillUnmount() {
    meta2d?.destroy();
  }

  _fetch(url, cb) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, true);
    xhr.send();
    xhr.onreadystatechange = function () {
      if (xhr.readyState === 4 && xhr.status === 200) {
        cb && cb(xhr.responseText);
      }
    };
  }

  registerBasicDiagram() {
    register(flowPens());
    registerAnchors(flowAnchors());
    register(activityDiagram());
    registerCanvasDraw(activityDiagramByCtx());
    register(classPens());
    register(sequencePens());
    registerCanvasDraw(sequencePensbyCtx());
    registerEcharts();
    registerHighcharts();
    registerLightningChart();
    register(formPath2DPens());
    registerCanvasDraw(formPens());
    registerCanvasDraw(chartsPens());
    register(ftaPens());
    registerCanvasDraw(ftaPensbyCtx());
    registerAnchors(ftaAnchors());
  }

  render() {
    return (
      <div className="content">
        <div id="meta2d"></div>
      </div>
    );
  }
}
